stm32-metapac

Crates

git

Versions

stm32u073hb

Flavors

Eccr

Struct Eccr 

#[repr(transparent)]
pub struct Eccr(pub u32);
FLASH ECC register

Tuple Fields

0: u32

Implementations



impl Eccr

pub const fn addr_ecc(&self) -> u16

ECC fail double-word address offset In case of ECC error or ECC correction detected, this bitfield contains double-word offset (multiple of 64 bits) to main Flash memory.

pub const fn set_addr_ecc(&mut self, val: u16)

ECC fail double-word address offset In case of ECC error or ECC correction detected, this bitfield contains double-word offset (multiple of 64 bits) to main Flash memory.

pub const fn sysf_ecc(&self) -> bool

System Flash memory ECC fail This bit indicates that the ECC error correction or double ECC error detection is located in the system Flash memory.

pub const fn set_sysf_ecc(&mut self, val: bool)

System Flash memory ECC fail This bit indicates that the ECC error correction or double ECC error detection is located in the system Flash memory.

pub const fn ecccie(&self) -> bool

ECC correction interrupt enable

pub const fn set_ecccie(&mut self, val: bool)

ECC correction interrupt enable

pub const fn eccc(&self) -> bool

ECC correction Set by hardware when one ECC error has been detected and corrected. An interrupt is generated if ECCIE is set. Cleared by writing 1.

pub const fn set_eccc(&mut self, val: bool)

ECC correction Set by hardware when one ECC error has been detected and corrected. An interrupt is generated if ECCIE is set. Cleared by writing 1.

pub const fn eccd(&self) -> bool

ECC detection Set by hardware when two ECC errors have been detected. When this bit is set, a NMI is generated. Cleared by writing 1.

pub const fn set_eccd(&mut self, val: bool)

ECC detection Set by hardware when two ECC errors have been detected. When this bit is set, a NMI is generated. Cleared by writing 1.